@@ -22,7 +22,7 @@ public:
     
     void append (nifti_image * const image, const std::string &name)
     {
-        RNifti::NiftiImage wrapper(image);
+        RNifti::NiftiImage wrapper(image, true);
         wrapper.setPersistence(true);
         Rcpp::RObject pointer = wrapper.toPointer(name);
         
